%bcond falcon 1

%global srcname openapi-core
%global modname openapi_core

Name:           python-%{srcname}
Version:        0.19.1
Release:        %autorelease
Summary:        OpenAPI client-side and server-side support

License:        BSD-3-Clause
URL:            https://github.com/python-openapi/%{srcname}
Source:         %{pypi_source %{modname}}

# Upstream now requires pytest 8, but it is not yet available in Fedora. All
# tests pass with the proposed pytest 8 in
# https://copr.fedorainfracloud.org/coprs/thrnciar/pytest/. Until it ships,
# we must revert the changes for pytest 8:
Patch:          0001-Revert-Pytest-8-upgrade.patch
# Fix a DeprecationWarning from aiohttp in TestPetPhotoView
# https://github.com/python-openapi/openapi-core/pull/836
#  Fixes:
# [Bug]: New DeprecationWarning with aiohttp 3.9.4
# https://github.com/python-openapi/openapi-core/issues/835
Patch:          %{url}/pull/836.patch

BuildArch:      noarch
BuildRequires:  python3-devel

# Test dependencies; see [tool.poetry.dev-dependencies], but note that this
# contains both test dependencies and unwanted linters etc.
BuildRequires:  python3dist(djangorestframework)
BuildRequires:  python3dist(httpx)
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(pytest-aiohttp)
BuildRequires:  python3dist(responses)
BuildRequires:  python3dist(strict-rfc3339)
BuildRequires:  python3dist(webob)

%global _description %{expand:
Openapi-core is a Python library that adds client-side and server-side
support for the OpenAPI v3.0 and OpenAPI v3.1 specification.}

%description %_description


%package -n     python3-%{srcname}
Summary:        %{summary}

%description -n python3-%{srcname} %_description


%pyproject_extras_subpkg -n python3-openapi-core aiohttp django %{?with_falcon:falcon} fastapi flask requests starlette


%prep
%autosetup -n %{modname}-%{version} -p1
# https://docs.fedoraproject.org/en-US/packaging-guidelines/Python/#_linters
sed -r -i '/^--cov[-=]/d' pyproject.toml
# We cannot respect a SemVer pin on FastAPI; it updates frequently, with
# usually-tiny breaking changes.
sed -r -i 's/(fastapi = \{version = ")\^/\1>=/' pyproject.toml


%generate_buildrequires

%pyproject_buildrequires -x aiohttp -x django %{?with_falcon:-x falcon} -x fastapi -x flask -x requests -x starlette


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files %{modname}


%check
%if %{without falcon}
ignore="${ignore-} --ignore=tests/integration/contrib/falcon"
%endif
%pytest ${ignore-}


%files -n python3-%{srcname} -f %{pyproject_files}
%license LICENSE
%doc README.rst


%changelog
%autochangelog
