%global upstreamname rocRAND

%global rocm_release 6.1
%global rocm_patch 1
%global rocm_version %{rocm_release}.%{rocm_patch}

%global toolchain rocm
# hipcc does not support some clang flags
%global build_cxxflags %(echo %{optflags} | sed -e 's/-fstack-protector-strong/-Xarch_host -fstack-protector-strong/' -e 's/-fcf-protection/-Xarch_host -fcf-protection/')

# $gpu will be evaluated in the loops below
%global _vpath_builddir %{_vendor}-%{_target_os}-build-${gpu}

# It is necessary to use this with a local build
# export QA_RPATHS=0xff
%bcond_with test

# Option to test suite for testing on real HW:
%bcond_with check

Name:           rocrand
Version:        %{rocm_version}
Release:        %autorelease
Summary:        ROCm random number generator

Url:            https://github.com/ROCm/rocRAND
License:        MIT and BSD
Source0:        %{url}/archive/refs/tags/rocm-%{version}.tar.gz#/%{upstreamname}-%{version}.tar.gz

BuildRequires:  git
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  ninja-build
BuildRequires:  rocm-cmake
BuildRequires:  rocm-comgr-devel
BuildRequires:  rocm-hip-devel
BuildRequires:  rocm-runtime-devel
BuildRequires:  rocm-rpm-macros
BuildRequires:  rocm-rpm-macros-modules

%if %{with test}
BuildRequires:  gtest-devel
%endif

Requires:       rocm-rpm-macros-modules

# Only x86_64 works right now:
ExclusiveArch:  x86_64

%description
The rocRAND project provides functions that generate pseudo-random and
quasi-random numbers.

The rocRAND library is implemented in the HIP programming language and
optimised for AMD's latest discrete GPUs. It is designed to run on top of AMD's
Radeon Open Compute ROCm runtime, but it also works on CUDA enabled GPUs.

%package devel
Summary:        The rocRAND development package
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{name}-gfx90a%{?_isa} = %{version}-%{release}
Requires:       %{name}-gfx942%{?_isa} = %{version}-%{release}
Requires:       %{name}-gfx1100%{?_isa} = %{version}-%{release}
Requires:       %{name}-gfx1103%{?_isa} = %{version}-%{release}

%description devel
The rocRAND development package.

%if %{with test}
%package test
Summary:        Tests for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description test
%{summary}
%endif

%package gfx90a
Summary:        %{name} for MI200
%description gfx90a
%{summary}

%package gfx942
Summary:        %{name} for MI300
%description gfx942
%{summary}

%package gfx1100
Summary:        %{name} for W7900
%description gfx1100
%{summary}

%package gfx1103
Summary:        %{name} for gfx1103 (experimental)
%description gfx1103
%{summary}

%prep
%autosetup -p1 -n %{upstreamname}-rocm-%{version}

%build
for gpu in %{rocm_gpu_list}
do
    module load rocm/$gpu
    %cmake -G Ninja \
           -DCMAKE_BUILD_TYPE=RelWithDebInfo \
           -DBUILD_FILE_REORG_BACKWARD_COMPATIBILITY=OFF \
	   -DROCM_SYMLINK_LIBS=OFF \
	   -DAMDGPU_TARGETS=${ROCM_GPUS} \
	   -DCMAKE_INSTALL_LIBDIR=$ROCM_LIB \
	   -DCMAKE_INSTALL_BINDIR=$ROCM_BIN \
%if %{with test}
           -DBUILD_TEST=ON
%endif

    %cmake_build
    module purge
done

%install
for gpu in %{rocm_gpu_list}
do
    %cmake_install
done

%check
%if %{with test}
%if %{with check}
# Assumes default
%ctest
%endif
%endif

%files
%doc README.md
%license %{_docdir}/%{name}/LICENSE.txt
%{_libdir}/lib%{name}.so.*
%{_libdir}/rocm/gfx{8,9,10,11}/lib/lib%{name}.so.*

%files gfx90a
%{_libdir}/rocm/gfx90a/lib/lib%{name}.so.*

%files gfx942
%{_libdir}/rocm/gfx942/lib/lib%{name}.so.*

%files gfx1100
%{_libdir}/rocm/gfx1100/lib/lib%{name}.so.*

%files gfx1103
%{_libdir}/rocm/gfx1103/lib/lib%{name}.so.*

%files devel
%dir %{_includedir}/%{name}
%dir %{_libdir}/cmake/%{name}
%{_includedir}/%{name}
%{_libdir}/cmake/%{name}/*
%{_libdir}/lib%{name}.so
%{_libdir}/rocm/gfx*/lib/lib%{name}.so
%{_libdir}/rocm/gfx*/lib/cmake/%{name}/*

%if %{with test}
%files test
%{_bindir}/test_*
%{_bindir}/*RAND/
%{_libdir}/rocm/gfx*/bin/*
%endif

%changelog
%autochangelog
